# coding: utf-8

"""
    Katib

    Swagger description for Katib  # noqa: E501

    The version of the OpenAPI document: v1beta1-0.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kubeflow.katib.configuration import Configuration


class V1beta1ExperimentStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'completion_time': 'datetime',
        'conditions': 'list[V1beta1ExperimentCondition]',
        'current_optimal_trial': 'V1beta1OptimalTrial',
        'early_stopped_trial_list': 'list[str]',
        'failed_trial_list': 'list[str]',
        'killed_trial_list': 'list[str]',
        'last_reconcile_time': 'datetime',
        'metrics_unavailable_trial_list': 'list[str]',
        'pending_trial_list': 'list[str]',
        'running_trial_list': 'list[str]',
        'start_time': 'datetime',
        'succeeded_trial_list': 'list[str]',
        'trial_metrics_unavailable': 'int',
        'trials': 'int',
        'trials_early_stopped': 'int',
        'trials_failed': 'int',
        'trials_killed': 'int',
        'trials_pending': 'int',
        'trials_running': 'int',
        'trials_succeeded': 'int'
    }

    attribute_map = {
        'completion_time': 'completionTime',
        'conditions': 'conditions',
        'current_optimal_trial': 'currentOptimalTrial',
        'early_stopped_trial_list': 'earlyStoppedTrialList',
        'failed_trial_list': 'failedTrialList',
        'killed_trial_list': 'killedTrialList',
        'last_reconcile_time': 'lastReconcileTime',
        'metrics_unavailable_trial_list': 'metricsUnavailableTrialList',
        'pending_trial_list': 'pendingTrialList',
        'running_trial_list': 'runningTrialList',
        'start_time': 'startTime',
        'succeeded_trial_list': 'succeededTrialList',
        'trial_metrics_unavailable': 'trialMetricsUnavailable',
        'trials': 'trials',
        'trials_early_stopped': 'trialsEarlyStopped',
        'trials_failed': 'trialsFailed',
        'trials_killed': 'trialsKilled',
        'trials_pending': 'trialsPending',
        'trials_running': 'trialsRunning',
        'trials_succeeded': 'trialsSucceeded'
    }

    def __init__(self, completion_time=None, conditions=None, current_optimal_trial=None, early_stopped_trial_list=None, failed_trial_list=None, killed_trial_list=None, last_reconcile_time=None, metrics_unavailable_trial_list=None, pending_trial_list=None, running_trial_list=None, start_time=None, succeeded_trial_list=None, trial_metrics_unavailable=None, trials=None, trials_early_stopped=None, trials_failed=None, trials_killed=None, trials_pending=None, trials_running=None, trials_succeeded=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1ExperimentStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._completion_time = None
        self._conditions = None
        self._current_optimal_trial = None
        self._early_stopped_trial_list = None
        self._failed_trial_list = None
        self._killed_trial_list = None
        self._last_reconcile_time = None
        self._metrics_unavailable_trial_list = None
        self._pending_trial_list = None
        self._running_trial_list = None
        self._start_time = None
        self._succeeded_trial_list = None
        self._trial_metrics_unavailable = None
        self._trials = None
        self._trials_early_stopped = None
        self._trials_failed = None
        self._trials_killed = None
        self._trials_pending = None
        self._trials_running = None
        self._trials_succeeded = None
        self.discriminator = None

        if completion_time is not None:
            self.completion_time = completion_time
        if conditions is not None:
            self.conditions = conditions
        if current_optimal_trial is not None:
            self.current_optimal_trial = current_optimal_trial
        if early_stopped_trial_list is not None:
            self.early_stopped_trial_list = early_stopped_trial_list
        if failed_trial_list is not None:
            self.failed_trial_list = failed_trial_list
        if killed_trial_list is not None:
            self.killed_trial_list = killed_trial_list
        if last_reconcile_time is not None:
            self.last_reconcile_time = last_reconcile_time
        if metrics_unavailable_trial_list is not None:
            self.metrics_unavailable_trial_list = metrics_unavailable_trial_list
        if pending_trial_list is not None:
            self.pending_trial_list = pending_trial_list
        if running_trial_list is not None:
            self.running_trial_list = running_trial_list
        if start_time is not None:
            self.start_time = start_time
        if succeeded_trial_list is not None:
            self.succeeded_trial_list = succeeded_trial_list
        if trial_metrics_unavailable is not None:
            self.trial_metrics_unavailable = trial_metrics_unavailable
        if trials is not None:
            self.trials = trials
        if trials_early_stopped is not None:
            self.trials_early_stopped = trials_early_stopped
        if trials_failed is not None:
            self.trials_failed = trials_failed
        if trials_killed is not None:
            self.trials_killed = trials_killed
        if trials_pending is not None:
            self.trials_pending = trials_pending
        if trials_running is not None:
            self.trials_running = trials_running
        if trials_succeeded is not None:
            self.trials_succeeded = trials_succeeded

    @property
    def completion_time(self):
        """Gets the completion_time of this V1beta1ExperimentStatus.  # noqa: E501


        :return: The completion_time of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._completion_time

    @completion_time.setter
    def completion_time(self, completion_time):
        """Sets the completion_time of this V1beta1ExperimentStatus.


        :param completion_time: The completion_time of this V1beta1ExperimentStatus.  # noqa: E501
        :type: datetime
        """

        self._completion_time = completion_time

    @property
    def conditions(self):
        """Gets the conditions of this V1beta1ExperimentStatus.  # noqa: E501

        List of observed runtime conditions for this Experiment.  # noqa: E501

        :return: The conditions of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: list[V1beta1ExperimentCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this V1beta1ExperimentStatus.

        List of observed runtime conditions for this Experiment.  # noqa: E501

        :param conditions: The conditions of this V1beta1ExperimentStatus.  # noqa: E501
        :type: list[V1beta1ExperimentCondition]
        """

        self._conditions = conditions

    @property
    def current_optimal_trial(self):
        """Gets the current_optimal_trial of this V1beta1ExperimentStatus.  # noqa: E501


        :return: The current_optimal_trial of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: V1beta1OptimalTrial
        """
        return self._current_optimal_trial

    @current_optimal_trial.setter
    def current_optimal_trial(self, current_optimal_trial):
        """Sets the current_optimal_trial of this V1beta1ExperimentStatus.


        :param current_optimal_trial: The current_optimal_trial of this V1beta1ExperimentStatus.  # noqa: E501
        :type: V1beta1OptimalTrial
        """

        self._current_optimal_trial = current_optimal_trial

    @property
    def early_stopped_trial_list(self):
        """Gets the early_stopped_trial_list of this V1beta1ExperimentStatus.  # noqa: E501

        List of trial names which have been early stopped.  # noqa: E501

        :return: The early_stopped_trial_list of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._early_stopped_trial_list

    @early_stopped_trial_list.setter
    def early_stopped_trial_list(self, early_stopped_trial_list):
        """Sets the early_stopped_trial_list of this V1beta1ExperimentStatus.

        List of trial names which have been early stopped.  # noqa: E501

        :param early_stopped_trial_list: The early_stopped_trial_list of this V1beta1ExperimentStatus.  # noqa: E501
        :type: list[str]
        """

        self._early_stopped_trial_list = early_stopped_trial_list

    @property
    def failed_trial_list(self):
        """Gets the failed_trial_list of this V1beta1ExperimentStatus.  # noqa: E501

        List of trial names which have already failed.  # noqa: E501

        :return: The failed_trial_list of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._failed_trial_list

    @failed_trial_list.setter
    def failed_trial_list(self, failed_trial_list):
        """Sets the failed_trial_list of this V1beta1ExperimentStatus.

        List of trial names which have already failed.  # noqa: E501

        :param failed_trial_list: The failed_trial_list of this V1beta1ExperimentStatus.  # noqa: E501
        :type: list[str]
        """

        self._failed_trial_list = failed_trial_list

    @property
    def killed_trial_list(self):
        """Gets the killed_trial_list of this V1beta1ExperimentStatus.  # noqa: E501

        List of trial names which have been killed.  # noqa: E501

        :return: The killed_trial_list of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._killed_trial_list

    @killed_trial_list.setter
    def killed_trial_list(self, killed_trial_list):
        """Sets the killed_trial_list of this V1beta1ExperimentStatus.

        List of trial names which have been killed.  # noqa: E501

        :param killed_trial_list: The killed_trial_list of this V1beta1ExperimentStatus.  # noqa: E501
        :type: list[str]
        """

        self._killed_trial_list = killed_trial_list

    @property
    def last_reconcile_time(self):
        """Gets the last_reconcile_time of this V1beta1ExperimentStatus.  # noqa: E501


        :return: The last_reconcile_time of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._last_reconcile_time

    @last_reconcile_time.setter
    def last_reconcile_time(self, last_reconcile_time):
        """Sets the last_reconcile_time of this V1beta1ExperimentStatus.


        :param last_reconcile_time: The last_reconcile_time of this V1beta1ExperimentStatus.  # noqa: E501
        :type: datetime
        """

        self._last_reconcile_time = last_reconcile_time

    @property
    def metrics_unavailable_trial_list(self):
        """Gets the metrics_unavailable_trial_list of this V1beta1ExperimentStatus.  # noqa: E501

        List of trial names which have been metrics unavailable  # noqa: E501

        :return: The metrics_unavailable_trial_list of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._metrics_unavailable_trial_list

    @metrics_unavailable_trial_list.setter
    def metrics_unavailable_trial_list(self, metrics_unavailable_trial_list):
        """Sets the metrics_unavailable_trial_list of this V1beta1ExperimentStatus.

        List of trial names which have been metrics unavailable  # noqa: E501

        :param metrics_unavailable_trial_list: The metrics_unavailable_trial_list of this V1beta1ExperimentStatus.  # noqa: E501
        :type: list[str]
        """

        self._metrics_unavailable_trial_list = metrics_unavailable_trial_list

    @property
    def pending_trial_list(self):
        """Gets the pending_trial_list of this V1beta1ExperimentStatus.  # noqa: E501

        List of trial names which are pending.  # noqa: E501

        :return: The pending_trial_list of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._pending_trial_list

    @pending_trial_list.setter
    def pending_trial_list(self, pending_trial_list):
        """Sets the pending_trial_list of this V1beta1ExperimentStatus.

        List of trial names which are pending.  # noqa: E501

        :param pending_trial_list: The pending_trial_list of this V1beta1ExperimentStatus.  # noqa: E501
        :type: list[str]
        """

        self._pending_trial_list = pending_trial_list

    @property
    def running_trial_list(self):
        """Gets the running_trial_list of this V1beta1ExperimentStatus.  # noqa: E501

        List of trial names which are running.  # noqa: E501

        :return: The running_trial_list of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._running_trial_list

    @running_trial_list.setter
    def running_trial_list(self, running_trial_list):
        """Sets the running_trial_list of this V1beta1ExperimentStatus.

        List of trial names which are running.  # noqa: E501

        :param running_trial_list: The running_trial_list of this V1beta1ExperimentStatus.  # noqa: E501
        :type: list[str]
        """

        self._running_trial_list = running_trial_list

    @property
    def start_time(self):
        """Gets the start_time of this V1beta1ExperimentStatus.  # noqa: E501


        :return: The start_time of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this V1beta1ExperimentStatus.


        :param start_time: The start_time of this V1beta1ExperimentStatus.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def succeeded_trial_list(self):
        """Gets the succeeded_trial_list of this V1beta1ExperimentStatus.  # noqa: E501

        List of trial names which have already succeeded.  # noqa: E501

        :return: The succeeded_trial_list of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._succeeded_trial_list

    @succeeded_trial_list.setter
    def succeeded_trial_list(self, succeeded_trial_list):
        """Sets the succeeded_trial_list of this V1beta1ExperimentStatus.

        List of trial names which have already succeeded.  # noqa: E501

        :param succeeded_trial_list: The succeeded_trial_list of this V1beta1ExperimentStatus.  # noqa: E501
        :type: list[str]
        """

        self._succeeded_trial_list = succeeded_trial_list

    @property
    def trial_metrics_unavailable(self):
        """Gets the trial_metrics_unavailable of this V1beta1ExperimentStatus.  # noqa: E501

        How many trials are currently metrics unavailable.  # noqa: E501

        :return: The trial_metrics_unavailable of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: int
        """
        return self._trial_metrics_unavailable

    @trial_metrics_unavailable.setter
    def trial_metrics_unavailable(self, trial_metrics_unavailable):
        """Sets the trial_metrics_unavailable of this V1beta1ExperimentStatus.

        How many trials are currently metrics unavailable.  # noqa: E501

        :param trial_metrics_unavailable: The trial_metrics_unavailable of this V1beta1ExperimentStatus.  # noqa: E501
        :type: int
        """

        self._trial_metrics_unavailable = trial_metrics_unavailable

    @property
    def trials(self):
        """Gets the trials of this V1beta1ExperimentStatus.  # noqa: E501

        Trials is the total number of trials owned by the experiment.  # noqa: E501

        :return: The trials of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: int
        """
        return self._trials

    @trials.setter
    def trials(self, trials):
        """Sets the trials of this V1beta1ExperimentStatus.

        Trials is the total number of trials owned by the experiment.  # noqa: E501

        :param trials: The trials of this V1beta1ExperimentStatus.  # noqa: E501
        :type: int
        """

        self._trials = trials

    @property
    def trials_early_stopped(self):
        """Gets the trials_early_stopped of this V1beta1ExperimentStatus.  # noqa: E501

        How many trials are currently early stopped.  # noqa: E501

        :return: The trials_early_stopped of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: int
        """
        return self._trials_early_stopped

    @trials_early_stopped.setter
    def trials_early_stopped(self, trials_early_stopped):
        """Sets the trials_early_stopped of this V1beta1ExperimentStatus.

        How many trials are currently early stopped.  # noqa: E501

        :param trials_early_stopped: The trials_early_stopped of this V1beta1ExperimentStatus.  # noqa: E501
        :type: int
        """

        self._trials_early_stopped = trials_early_stopped

    @property
    def trials_failed(self):
        """Gets the trials_failed of this V1beta1ExperimentStatus.  # noqa: E501

        How many trials have failed.  # noqa: E501

        :return: The trials_failed of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: int
        """
        return self._trials_failed

    @trials_failed.setter
    def trials_failed(self, trials_failed):
        """Sets the trials_failed of this V1beta1ExperimentStatus.

        How many trials have failed.  # noqa: E501

        :param trials_failed: The trials_failed of this V1beta1ExperimentStatus.  # noqa: E501
        :type: int
        """

        self._trials_failed = trials_failed

    @property
    def trials_killed(self):
        """Gets the trials_killed of this V1beta1ExperimentStatus.  # noqa: E501

        How many trials have been killed.  # noqa: E501

        :return: The trials_killed of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: int
        """
        return self._trials_killed

    @trials_killed.setter
    def trials_killed(self, trials_killed):
        """Sets the trials_killed of this V1beta1ExperimentStatus.

        How many trials have been killed.  # noqa: E501

        :param trials_killed: The trials_killed of this V1beta1ExperimentStatus.  # noqa: E501
        :type: int
        """

        self._trials_killed = trials_killed

    @property
    def trials_pending(self):
        """Gets the trials_pending of this V1beta1ExperimentStatus.  # noqa: E501

        How many trials are currently pending.  # noqa: E501

        :return: The trials_pending of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: int
        """
        return self._trials_pending

    @trials_pending.setter
    def trials_pending(self, trials_pending):
        """Sets the trials_pending of this V1beta1ExperimentStatus.

        How many trials are currently pending.  # noqa: E501

        :param trials_pending: The trials_pending of this V1beta1ExperimentStatus.  # noqa: E501
        :type: int
        """

        self._trials_pending = trials_pending

    @property
    def trials_running(self):
        """Gets the trials_running of this V1beta1ExperimentStatus.  # noqa: E501

        How many trials are currently running.  # noqa: E501

        :return: The trials_running of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: int
        """
        return self._trials_running

    @trials_running.setter
    def trials_running(self, trials_running):
        """Sets the trials_running of this V1beta1ExperimentStatus.

        How many trials are currently running.  # noqa: E501

        :param trials_running: The trials_running of this V1beta1ExperimentStatus.  # noqa: E501
        :type: int
        """

        self._trials_running = trials_running

    @property
    def trials_succeeded(self):
        """Gets the trials_succeeded of this V1beta1ExperimentStatus.  # noqa: E501

        How many trials have succeeded.  # noqa: E501

        :return: The trials_succeeded of this V1beta1ExperimentStatus.  # noqa: E501
        :rtype: int
        """
        return self._trials_succeeded

    @trials_succeeded.setter
    def trials_succeeded(self, trials_succeeded):
        """Sets the trials_succeeded of this V1beta1ExperimentStatus.

        How many trials have succeeded.  # noqa: E501

        :param trials_succeeded: The trials_succeeded of this V1beta1ExperimentStatus.  # noqa: E501
        :type: int
        """

        self._trials_succeeded = trials_succeeded

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1ExperimentStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1ExperimentStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Katib

    Swagger description for Katib  # noqa: E501

    The version of the OpenAPI document: v1beta1-0.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kubeflow.katib.configuration import Configuration


class V1beta1SuggestionStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'algorithm_settings': 'list[V1beta1AlgorithmSetting]',
        'completion_time': 'datetime',
        'conditions': 'list[V1beta1SuggestionCondition]',
        'last_reconcile_time': 'datetime',
        'start_time': 'datetime',
        'suggestion_count': 'int',
        'suggestions': 'list[V1beta1TrialAssignment]'
    }

    attribute_map = {
        'algorithm_settings': 'algorithmSettings',
        'completion_time': 'completionTime',
        'conditions': 'conditions',
        'last_reconcile_time': 'lastReconcileTime',
        'start_time': 'startTime',
        'suggestion_count': 'suggestionCount',
        'suggestions': 'suggestions'
    }

    def __init__(self, algorithm_settings=None, completion_time=None, conditions=None, last_reconcile_time=None, start_time=None, suggestion_count=None, suggestions=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1SuggestionStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._algorithm_settings = None
        self._completion_time = None
        self._conditions = None
        self._last_reconcile_time = None
        self._start_time = None
        self._suggestion_count = None
        self._suggestions = None
        self.discriminator = None

        if algorithm_settings is not None:
            self.algorithm_settings = algorithm_settings
        if completion_time is not None:
            self.completion_time = completion_time
        if conditions is not None:
            self.conditions = conditions
        if last_reconcile_time is not None:
            self.last_reconcile_time = last_reconcile_time
        if start_time is not None:
            self.start_time = start_time
        if suggestion_count is not None:
            self.suggestion_count = suggestion_count
        if suggestions is not None:
            self.suggestions = suggestions

    @property
    def algorithm_settings(self):
        """Gets the algorithm_settings of this V1beta1SuggestionStatus.  # noqa: E501

        AlgorithmSettings defines HP or NAS algorithm settings which suggestion gRPC service returns. These settings overwrites Experiment's settings before the gRPC request. It can be empty if settings haven't been changed.  # noqa: E501

        :return: The algorithm_settings of this V1beta1SuggestionStatus.  # noqa: E501
        :rtype: list[V1beta1AlgorithmSetting]
        """
        return self._algorithm_settings

    @algorithm_settings.setter
    def algorithm_settings(self, algorithm_settings):
        """Sets the algorithm_settings of this V1beta1SuggestionStatus.

        AlgorithmSettings defines HP or NAS algorithm settings which suggestion gRPC service returns. These settings overwrites Experiment's settings before the gRPC request. It can be empty if settings haven't been changed.  # noqa: E501

        :param algorithm_settings: The algorithm_settings of this V1beta1SuggestionStatus.  # noqa: E501
        :type: list[V1beta1AlgorithmSetting]
        """

        self._algorithm_settings = algorithm_settings

    @property
    def completion_time(self):
        """Gets the completion_time of this V1beta1SuggestionStatus.  # noqa: E501


        :return: The completion_time of this V1beta1SuggestionStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._completion_time

    @completion_time.setter
    def completion_time(self, completion_time):
        """Sets the completion_time of this V1beta1SuggestionStatus.


        :param completion_time: The completion_time of this V1beta1SuggestionStatus.  # noqa: E501
        :type: datetime
        """

        self._completion_time = completion_time

    @property
    def conditions(self):
        """Gets the conditions of this V1beta1SuggestionStatus.  # noqa: E501

        List of observed runtime conditions for this Suggestion.  # noqa: E501

        :return: The conditions of this V1beta1SuggestionStatus.  # noqa: E501
        :rtype: list[V1beta1SuggestionCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this V1beta1SuggestionStatus.

        List of observed runtime conditions for this Suggestion.  # noqa: E501

        :param conditions: The conditions of this V1beta1SuggestionStatus.  # noqa: E501
        :type: list[V1beta1SuggestionCondition]
        """

        self._conditions = conditions

    @property
    def last_reconcile_time(self):
        """Gets the last_reconcile_time of this V1beta1SuggestionStatus.  # noqa: E501


        :return: The last_reconcile_time of this V1beta1SuggestionStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._last_reconcile_time

    @last_reconcile_time.setter
    def last_reconcile_time(self, last_reconcile_time):
        """Sets the last_reconcile_time of this V1beta1SuggestionStatus.


        :param last_reconcile_time: The last_reconcile_time of this V1beta1SuggestionStatus.  # noqa: E501
        :type: datetime
        """

        self._last_reconcile_time = last_reconcile_time

    @property
    def start_time(self):
        """Gets the start_time of this V1beta1SuggestionStatus.  # noqa: E501


        :return: The start_time of this V1beta1SuggestionStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this V1beta1SuggestionStatus.


        :param start_time: The start_time of this V1beta1SuggestionStatus.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def suggestion_count(self):
        """Gets the suggestion_count of this V1beta1SuggestionStatus.  # noqa: E501

        Number of suggestion results  # noqa: E501

        :return: The suggestion_count of this V1beta1SuggestionStatus.  # noqa: E501
        :rtype: int
        """
        return self._suggestion_count

    @suggestion_count.setter
    def suggestion_count(self, suggestion_count):
        """Sets the suggestion_count of this V1beta1SuggestionStatus.

        Number of suggestion results  # noqa: E501

        :param suggestion_count: The suggestion_count of this V1beta1SuggestionStatus.  # noqa: E501
        :type: int
        """

        self._suggestion_count = suggestion_count

    @property
    def suggestions(self):
        """Gets the suggestions of this V1beta1SuggestionStatus.  # noqa: E501

        Suggestion results  # noqa: E501

        :return: The suggestions of this V1beta1SuggestionStatus.  # noqa: E501
        :rtype: list[V1beta1TrialAssignment]
        """
        return self._suggestions

    @suggestions.setter
    def suggestions(self, suggestions):
        """Sets the suggestions of this V1beta1SuggestionStatus.

        Suggestion results  # noqa: E501

        :param suggestions: The suggestions of this V1beta1SuggestionStatus.  # noqa: E501
        :type: list[V1beta1TrialAssignment]
        """

        self._suggestions = suggestions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1SuggestionStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1SuggestionStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Katib

    Swagger description for Katib  # noqa: E501

    The version of the OpenAPI document: v1beta1-0.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kubeflow.katib.configuration import Configuration


class V1beta1ObjectiveSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'additional_metric_names': 'list[str]',
        'goal': 'float',
        'metric_strategies': 'list[V1beta1MetricStrategy]',
        'objective_metric_name': 'str',
        'type': 'str'
    }

    attribute_map = {
        'additional_metric_names': 'additionalMetricNames',
        'goal': 'goal',
        'metric_strategies': 'metricStrategies',
        'objective_metric_name': 'objectiveMetricName',
        'type': 'type'
    }

    def __init__(self, additional_metric_names=None, goal=None, metric_strategies=None, objective_metric_name=None, type=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1ObjectiveSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._additional_metric_names = None
        self._goal = None
        self._metric_strategies = None
        self._objective_metric_name = None
        self._type = None
        self.discriminator = None

        if additional_metric_names is not None:
            self.additional_metric_names = additional_metric_names
        if goal is not None:
            self.goal = goal
        if metric_strategies is not None:
            self.metric_strategies = metric_strategies
        if objective_metric_name is not None:
            self.objective_metric_name = objective_metric_name
        if type is not None:
            self.type = type

    @property
    def additional_metric_names(self):
        """Gets the additional_metric_names of this V1beta1ObjectiveSpec.  # noqa: E501

        AdditionalMetricNames represents metrics that should be collected from Trials. This can be empty if we only care about the objective metric. Note: If we adopt a push instead of pull mechanism, this can be omitted completely.  # noqa: E501

        :return: The additional_metric_names of this V1beta1ObjectiveSpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._additional_metric_names

    @additional_metric_names.setter
    def additional_metric_names(self, additional_metric_names):
        """Sets the additional_metric_names of this V1beta1ObjectiveSpec.

        AdditionalMetricNames represents metrics that should be collected from Trials. This can be empty if we only care about the objective metric. Note: If we adopt a push instead of pull mechanism, this can be omitted completely.  # noqa: E501

        :param additional_metric_names: The additional_metric_names of this V1beta1ObjectiveSpec.  # noqa: E501
        :type: list[str]
        """

        self._additional_metric_names = additional_metric_names

    @property
    def goal(self):
        """Gets the goal of this V1beta1ObjectiveSpec.  # noqa: E501

        Goal is the Experiment's objective goal that should be reached. In case of empty goal, Experiment is running until MaxTrialCount = TrialsSucceeded.  # noqa: E501

        :return: The goal of this V1beta1ObjectiveSpec.  # noqa: E501
        :rtype: float
        """
        return self._goal

    @goal.setter
    def goal(self, goal):
        """Sets the goal of this V1beta1ObjectiveSpec.

        Goal is the Experiment's objective goal that should be reached. In case of empty goal, Experiment is running until MaxTrialCount = TrialsSucceeded.  # noqa: E501

        :param goal: The goal of this V1beta1ObjectiveSpec.  # noqa: E501
        :type: float
        """

        self._goal = goal

    @property
    def metric_strategies(self):
        """Gets the metric_strategies of this V1beta1ObjectiveSpec.  # noqa: E501

        MetricStrategies defines various rules (min, max or latest) to extract metrics values. This field is allowed to missing, experiment defaulter (webhook) will fill it.  # noqa: E501

        :return: The metric_strategies of this V1beta1ObjectiveSpec.  # noqa: E501
        :rtype: list[V1beta1MetricStrategy]
        """
        return self._metric_strategies

    @metric_strategies.setter
    def metric_strategies(self, metric_strategies):
        """Sets the metric_strategies of this V1beta1ObjectiveSpec.

        MetricStrategies defines various rules (min, max or latest) to extract metrics values. This field is allowed to missing, experiment defaulter (webhook) will fill it.  # noqa: E501

        :param metric_strategies: The metric_strategies of this V1beta1ObjectiveSpec.  # noqa: E501
        :type: list[V1beta1MetricStrategy]
        """

        self._metric_strategies = metric_strategies

    @property
    def objective_metric_name(self):
        """Gets the objective_metric_name of this V1beta1ObjectiveSpec.  # noqa: E501

        ObjectiveMetricName represents primary Experiment's metric to optimize.  # noqa: E501

        :return: The objective_metric_name of this V1beta1ObjectiveSpec.  # noqa: E501
        :rtype: str
        """
        return self._objective_metric_name

    @objective_metric_name.setter
    def objective_metric_name(self, objective_metric_name):
        """Sets the objective_metric_name of this V1beta1ObjectiveSpec.

        ObjectiveMetricName represents primary Experiment's metric to optimize.  # noqa: E501

        :param objective_metric_name: The objective_metric_name of this V1beta1ObjectiveSpec.  # noqa: E501
        :type: str
        """

        self._objective_metric_name = objective_metric_name

    @property
    def type(self):
        """Gets the type of this V1beta1ObjectiveSpec.  # noqa: E501

        Type for Experiment optimization.  # noqa: E501

        :return: The type of this V1beta1ObjectiveSpec.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this V1beta1ObjectiveSpec.

        Type for Experiment optimization.  # noqa: E501

        :param type: The type of this V1beta1ObjectiveSpec.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1ObjectiveSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1ObjectiveSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Katib

    Swagger description for Katib  # noqa: E501

    The version of the OpenAPI document: v1beta1-0.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kubeflow.katib.configuration import Configuration


class V1beta1ConfigMapSource(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'config_map_name': 'str',
        'config_map_namespace': 'str',
        'template_path': 'str'
    }

    attribute_map = {
        'config_map_name': 'configMapName',
        'config_map_namespace': 'configMapNamespace',
        'template_path': 'templatePath'
    }

    def __init__(self, config_map_name=None, config_map_namespace=None, template_path=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1ConfigMapSource - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._config_map_name = None
        self._config_map_namespace = None
        self._template_path = None
        self.discriminator = None

        if config_map_name is not None:
            self.config_map_name = config_map_name
        if config_map_namespace is not None:
            self.config_map_namespace = config_map_namespace
        if template_path is not None:
            self.template_path = template_path

    @property
    def config_map_name(self):
        """Gets the config_map_name of this V1beta1ConfigMapSource.  # noqa: E501

        Name of config map where trial template is located  # noqa: E501

        :return: The config_map_name of this V1beta1ConfigMapSource.  # noqa: E501
        :rtype: str
        """
        return self._config_map_name

    @config_map_name.setter
    def config_map_name(self, config_map_name):
        """Sets the config_map_name of this V1beta1ConfigMapSource.

        Name of config map where trial template is located  # noqa: E501

        :param config_map_name: The config_map_name of this V1beta1ConfigMapSource.  # noqa: E501
        :type: str
        """

        self._config_map_name = config_map_name

    @property
    def config_map_namespace(self):
        """Gets the config_map_namespace of this V1beta1ConfigMapSource.  # noqa: E501

        Namespace of config map where trial template is located  # noqa: E501

        :return: The config_map_namespace of this V1beta1ConfigMapSource.  # noqa: E501
        :rtype: str
        """
        return self._config_map_namespace

    @config_map_namespace.setter
    def config_map_namespace(self, config_map_namespace):
        """Sets the config_map_namespace of this V1beta1ConfigMapSource.

        Namespace of config map where trial template is located  # noqa: E501

        :param config_map_namespace: The config_map_namespace of this V1beta1ConfigMapSource.  # noqa: E501
        :type: str
        """

        self._config_map_namespace = config_map_namespace

    @property
    def template_path(self):
        """Gets the template_path of this V1beta1ConfigMapSource.  # noqa: E501

        Path in config map where trial template is located  # noqa: E501

        :return: The template_path of this V1beta1ConfigMapSource.  # noqa: E501
        :rtype: str
        """
        return self._template_path

    @template_path.setter
    def template_path(self, template_path):
        """Sets the template_path of this V1beta1ConfigMapSource.

        Path in config map where trial template is located  # noqa: E501

        :param template_path: The template_path of this V1beta1ConfigMapSource.  # noqa: E501
        :type: str
        """

        self._template_path = template_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1ConfigMapSource):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1ConfigMapSource):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Katib

    Swagger description for Katib  # noqa: E501

    The version of the OpenAPI document: v1beta1-0.1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kubeflow.katib.configuration import Configuration


class V1beta1SourceSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'file_system_path': 'V1beta1FileSystemPath',
        'filter': 'V1beta1FilterSpec',
        'http_get': 'V1HTTPGetAction'
    }

    attribute_map = {
        'file_system_path': 'fileSystemPath',
        'filter': 'filter',
        'http_get': 'httpGet'
    }

    def __init__(self, file_system_path=None, filter=None, http_get=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1SourceSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._file_system_path = None
        self._filter = None
        self._http_get = None
        self.discriminator = None

        if file_system_path is not None:
            self.file_system_path = file_system_path
        if filter is not None:
            self.filter = filter
        if http_get is not None:
            self.http_get = http_get

    @property
    def file_system_path(self):
        """Gets the file_system_path of this V1beta1SourceSpec.  # noqa: E501


        :return: The file_system_path of this V1beta1SourceSpec.  # noqa: E501
        :rtype: V1beta1FileSystemPath
        """
        return self._file_system_path

    @file_system_path.setter
    def file_system_path(self, file_system_path):
        """Sets the file_system_path of this V1beta1SourceSpec.


        :param file_system_path: The file_system_path of this V1beta1SourceSpec.  # noqa: E501
        :type: V1beta1FileSystemPath
        """

        self._file_system_path = file_system_path

    @property
    def filter(self):
        """Gets the filter of this V1beta1SourceSpec.  # noqa: E501


        :return: The filter of this V1beta1SourceSpec.  # noqa: E501
        :rtype: V1beta1FilterSpec
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """Sets the filter of this V1beta1SourceSpec.


        :param filter: The filter of this V1beta1SourceSpec.  # noqa: E501
        :type: V1beta1FilterSpec
        """

        self._filter = filter

    @property
    def http_get(self):
        """Gets the http_get of this V1beta1SourceSpec.  # noqa: E501


        :return: The http_get of this V1beta1SourceSpec.  # noqa: E501
        :rtype: V1HTTPGetAction
        """
        return self._http_get

    @http_get.setter
    def http_get(self, http_get):
        """Sets the http_get of this V1beta1SourceSpec.


        :param http_get: The http_get of this V1beta1SourceSpec.  # noqa: E501
        :type: V1HTTPGetAction
        """

        self._http_get = http_get

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1SourceSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1SourceSpec):
            return True

        return self.to_dict() != other.to_dict()
